@@ -4,13 +4,14 @@
 #' @return A list with DeltaAIC and Akaike weight for the models.
 #' @param ... Successive results to be compared as lists.
 #' @param factor.value The $value of the list object is multiplied by factor.value to calculate AIC.
-#' @description This function is used to compares the AIC of several outputs obtained with the same data but with different set of parameters.\cr
+#' @description This function is used to compare the AIC of several outputs obtained with the same data but with different set of parameters.\cr
 #' The parameters must be lists with $aic or $AIC or $value and $par elements or if AIC(element) is defined.\cr
 #' if \code{$value} and \code{$par} are present in the object, the AIC is calculated as \code{2*factor.value*value+2*length(par)}. If \code{$value} is -log(likeihood), then factor.value must be 1 and if \code{$value} is log(likeihood), then factor.value must be -1.\cr
 #' If several objects are within the same list, their AIC are summed.\cr
 #' For example, compare_AIC(g1=list(group), g2=list(separe1, separe2)) can be used to compare a single model onto two different sets of data against each set of data fited with its own set of parameters.\cr
 #' Take a look at \code{ICtab} in package \code{bbmle} which is similar.
 #' @examples
+#' \dontrun{
 #' library("HelpersMG")
 #' # Here two different models are fitted
 #' x <- 1:30
@@ -32,6 +33,7 @@
 #' d_grouped <- data.frame(x=x_grouped, y=y_grouped)
 #' m1_grouped <- lm(y ~ x, data=d_grouped)
 #' compare_AIC(separate=list(m1, m1_2), grouped=m1_grouped)
+#' }
 #' @export
 
 
@@ -42,14 +44,12 @@ if (is.list(result) & length(result)==1) result <- unlist(result, recursive=FALS
 
 if (!is.null(result)) {
 	if (!is.list(result) || (is.null(names(result))) || (any(names(result)==""))) {
-		print("The results must be included within a list with names; see example.")
-		return(invisible())
+		stop("The results must be included within a list with names; see example.")
 	} else {
 	out<-NULL
 	l<-length(result)
 		if (l<2) {
-			print("A least two results must be provided.")
-			return(invisible())
+			stop("A least two results must be provided.")
 		} else {
 			aic<-NULL
 			name<-names(result)
@@ -74,8 +74,7 @@ if (!is.null(result)) {
                 AICencours <- 2*factor.value*encours2$value+2*(length(encours2$par))
             if (is.null(AICencours))
               {
-                print(paste("Object", name[i], "has not the required format"))
-                return(invisible())
+                stop(paste("Object", name[i], "has not the required format"))
               }
             sumAIC <- sumAIC + AICencours
             }
@@ -84,7 +83,7 @@ if (!is.null(result)) {
 			}
 			
 			bestaic<-min(aic)
-			ser<-which(aic==bestaic)
+			ser<-which.min(aic)
 			deltaaic<-aic-bestaic
 			aw<-exp(-0.5*deltaaic)
 			saw=sum(aw)
